aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-pop.c
diff options
context:
space:
mode:
authorGerald Combs <gerald@wireshark.org>2018-09-13 08:40:27 -0700
committerGerald Combs <gerald@wireshark.org>2018-09-13 22:37:52 +0000
commitcd95e197ca78feb1e83ec737b87ada0a1dd57d10 (patch)
tree7d54d8cc9b6170acff8ca618b6d0eb5fa439f4f6 /epan/dissectors/packet-pop.c
parent63743a3733441a4f54ca6216ad63654bb3012824 (diff)
Start renaming SSL to TLS.
Rename the "ssl" protocol to "tls" and add an "ssl" alias. Prefer "TLS" over "SSL" in user interface text and in the documentation. Fix the test_tls_master_secret test while we're here. Bug: 14922 Change-Id: Iab6ba2c7c4c0f8f6dd0f6d5d90fac5e9486612f8 Reviewed-on: https://code.wireshark.org/review/29649 Petri-Dish: Gerald Combs <gerald@wireshark.org> Reviewed-by: Peter Wu <peter@lekensteyn.nl> Tested-by: Petri Dish Buildbot Reviewed-by: Gerald Combs <gerald@wireshark.org>
Diffstat (limited to 'epan/dissectors/packet-pop.c')
-rw-r--r--epan/dissectors/packet-pop.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/epan/dissectors/packet-pop.c b/epan/dissectors/packet-pop.c
index 469d28f013..b9845204cd 100644
--- a/epan/dissectors/packet-pop.c
+++ b/epan/dissectors/packet-pop.c
@@ -66,7 +66,7 @@ static gint ett_pop_data_fragments = -1;
static dissector_handle_t pop_handle;
static dissector_handle_t imf_handle;
-static dissector_handle_t ssl_handle;
+static dissector_handle_t tls_handle;
#define TCP_PORT_POP 110
#define TCP_PORT_SSL_POP 995
@@ -293,7 +293,7 @@ dissect_pop(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, void* data _U_)
if (data_val->stls_request) {
if (g_ascii_strncasecmp(line, "+OK ", 4) == 0) {
/* This is the last non-TLS frame. */
- ssl_starttls_ack(ssl_handle, pinfo, pop_handle);
+ ssl_starttls_ack(tls_handle, pinfo, pop_handle);
}
data_val->stls_request = FALSE;
}
@@ -467,8 +467,8 @@ proto_reg_handoff_pop(void)
/* find the IMF dissector */
imf_handle = find_dissector_add_dependency("imf", proto_pop);
- /* find the SSL dissector */
- ssl_handle = find_dissector_add_dependency("ssl", proto_pop);
+ /* find the TLS dissector */
+ tls_handle = find_dissector_add_dependency("tls", proto_pop);
}
/*